@@ -1,8 +1,6 @@
 #' Column Bind an Atomic Vector's Values with Its Names
 #'
-#' \code{\link[base]{cbind}} a named atomic \code{\link[base]{vector}}'s values
-#' with its \code{\link[base]{names}} to form \code{id} (from the names) and
-#' \code{content} columns.
+#' Deprecated, use \code{\link[textshape]{tidy_vector}} instead.
 #'
 #' @param x A named atomic \code{\link[base]{vector}}.
 #' @param id.name The name to use for the column created from the \code{\link[base]{vector}}
@@ -14,10 +12,14 @@
 #' from the \code{\link[base]{vector}} as an \code{id} column.
 #' @export
 #' @examples
+#' \dontrun{
 #' x <- setNames(sample(LETTERS[1:6], 1000, TRUE), sample(state.name[1:5], 1000, TRUE))
 #' bind_vector(x)
+#' }
 bind_vector <- function(x, id.name= "id", content.name = "content", ...){
 
+    warning("Deprecated, use textshape::tidy_vector() instead.", call. = FALSE)
+
     stopifnot(is.atomic(x))
     if (is.null(names)) {
         out <- data.table::as.data.table(x)
