@@ -6,6 +6,12 @@
 #' @param text.var The name of the text variable.  If \code{TRUE}
 #' \code{split_token} tries to detect the text column with tokens.
 #' @param lower logical.  If \code{TRUE} the words are converted to lower case.
+#' @param as.tibble logical.  If \code{TRUE} the output class will be set to a
+#' \pkg{tibble}, otherwise a \code{\link[data.table]{data.table}}.  Default
+#' checks \code{getOption("tibble.out")} as a logical.  If this is \code{NULL}
+#' the default \code{\link[textshape]{tibble_output}} will set \code{as.tibble}
+#' to \code{TRUE} if \pkg{dplyr} is loaded.  Otherwise, the output will be a
+#' \code{\link[data.table]{data.table}}.
 #' @param \ldots Ignored.
 #' @export
 #' @rdname split_token
@@ -44,7 +50,7 @@ split_token.default <- function(x, lower = TRUE, ...) {
 #' @export
 #' @rdname split_token
 #' @method split_token data.frame
-split_token.data.frame <- function(x, text.var = TRUE, lower = TRUE, ...) {
+split_token.data.frame <- function(x, text.var = TRUE, lower = TRUE, as.tibble = tibble_output(), ...) {
 
     element_id <- NULL
     nms <- colnames(x)
@@ -64,6 +70,6 @@ split_token.data.frame <- function(x, text.var = TRUE, lower = TRUE, ...) {
 
     express2 <- parse(text=paste0(".(", text.var, "=unlist(", text.var, "))"))
     z <- z[, eval(express2), by = c(colnames(z)[!colnames(z) %in% text.var])][, c(nms, "element_id"), with = FALSE]
-    z[, 'sentence_id' := 1:.N, by = list(element_id)][]
+    if_tibble(z[, 'sentence_id' := 1:.N, by = list(element_id)][], as.tibble = as.tibble)
 
 }
